<template>
  <div class="dashboard-item-wrapper">
    <div class="dashboard-item-title-wrapper">
      <img class="dashboard-item-title-icon" :src="icon" />
      <div class="dashboard-item-title">{{ title }}</div>
    </div>
    <div class="dashboard-item-value-wrapper">
      <div class="dashboard-item-symbol" v-if="needSymbol" v-html="showSymbol"></div>
      <div class="dashboard-item-value">{{ value }}</div>
    </div>
  </div>
</template>

<script setup lang="ts">
import { computed } from 'vue';

defineOptions({
  name: 'DashboardItem',
});

type Props = {
  icon?: string;
  title?: string;
  value?: string | number;
  needSymbol?: boolean;
  symbol?: string;
};

const props = withDefaults(defineProps<Props>(), {
  needSymbol: false,
  symbol: '&yen;',
});

const replaceSpecialChar = (url: string) => {
  url = url.replace(/&quot;/g, '"');
  url = url.replace(/&amp;/g, '&');
  url = url.replace(/&lt;/g, '<');
  url = url.replace(/&gt;/g, '>');
  url = url.replace(/&nbsp;/g, ' ');
  url = url.replace(/&yen;/g, '￥');
  return url;
};

const showSymbol = computed(() => {
  const symbol = props.needSymbol ? replaceSpecialChar(props.symbol) : '';
  return symbol;
});
</script>
